bayespy.inference.vmp.nodes.beta.BetaDistribution.plates_from_parent
====================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.beta

.. automethod:: BetaDistribution.plates_from_parent